==> estateplat-common-1.2.3-20180103.012305-3-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfKfxm.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-5
 * @description 新建商品房开发项目表
 */
@Table(name = "fcjy_xjspf_kfxm")
public class FcjyXjspfKfxm {
    @Id
    private String xmid;//主键
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String xsmc;//销售名称
    private String qxh;//区县号
    private String xmdz;//项目地址
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private Date kprq;//开盘日期
    private Date rzrq;//入住日期
    private String sldh;//售楼电话
    private String sldz;//售楼地址
    private String tdsyqzh;//土地使用权证号
    private String tddj;//土地等级(土地等级字典表)
    private String ghyt;//规划用途(土地用途字典表)
    private Integer zts;//总套数
    private Double zjzmj;//总建筑面积(平方米)
    private String szfw;//四至范围
    private Double zdmj;//占地面积(平方米)
    private Integer zrzs;//自然幢数
    private Integer dqksts;//当前可售套数
    private Double dqksmj;//当前可售面积
    private Integer yydts;//已预定套数
    private Integer ysts;//已售套数
    private String sfdjglxq;//是否多家管理小区(0:不是1：是)
    private String sfzzgzjxq;//是否整治改造旧小区(0:不是1：是 )
    private String sfwwpfmysxq;//是否五万平方米以上小区(0:不是1：是)
    private String lpjj;//楼盘简介
    private String sbzx;//设备装修
    private String sgjd;//施工进度
    private String ptss;//配套设施
    private String zwjt;//周围交通
    private String lhl;//绿化率
    private String rjl;//容积率
    private Double jzmd;//建筑密度
    private Integer cwgs;//车位个数
    private String jsydghxkzh;//建设用地规划许可证号
    private Integer bkbh;//板块编号
    private Integer mbsl;//模板数量
    private Double tdtz;//土地投资（万元）
    private Double jhzjzmj;//计划总建筑面积（平方米）
    private Double jhztz;//计划总投资（万元）
    private Date jhkgsj;//计划开工时间
    private Date jhjgsj;//计划竣工时间
    private Double sjwctz;//实际完成投资（万元）
    private Date sjkgsj;//实际开工时间
    private Date sjjgsj;//实际竣工时间
    private String bz;//备注
    private String sfzx;//是否注销(0：未注销1：注销 )
    private String zxyy;//注销原因
    private String wygs;//物业公司

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXsmc() {
        return xsmc;
    }

    public void setXsmc(String xsmc) {
        this.xsmc = xsmc;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getXmdz() {
        return xmdz;
    }

    public void setXmdz(String xmdz) {
        this.xmdz = xmdz;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public Date getKprq() {
        return kprq;
    }

    public void setKprq(Date kprq) {
        this.kprq = kprq;
    }

    public Date getRzrq() {
        return rzrq;
    }

    public void setRzrq(Date rzrq) {
        this.rzrq = rzrq;
    }

    public String getSldh() {
        return sldh;
    }

    public void setSldh(String sldh) {
        this.sldh = sldh;
    }

    public String getSldz() {
        return sldz;
    }

    public void setSldz(String sldz) {
        this.sldz = sldz;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public String getSzfw() {
        return szfw;
    }

    public void setSzfw(String szfw) {
        this.szfw = szfw;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public Integer getZrzs() {
        return zrzs;
    }

    public void setZrzs(Integer zrzs) {
        this.zrzs = zrzs;
    }

    public Integer getDqksts() {
        return dqksts;
    }

    public void setDqksts(Integer dqksts) {
        this.dqksts = dqksts;
    }

    public Double getDqksmj() {
        return dqksmj;
    }

    public void setDqksmj(Double dqksmj) {
        this.dqksmj = dqksmj;
    }

    public Integer getYydts() {
        return yydts;
    }

    public void setYydts(Integer yydts) {
        this.yydts = yydts;
    }

    public Integer getYsts() {
        return ysts;
    }

    public void setYsts(Integer ysts) {
        this.ysts = ysts;
    }

    public String getSfdjglxq() {
        return sfdjglxq;
    }

    public void setSfdjglxq(String sfdjglxq) {
        this.sfdjglxq = sfdjglxq;
    }

    public String getSfzzgzjxq() {
        return sfzzgzjxq;
    }

    public void setSfzzgzjxq(String sfzzgzjxq) {
        this.sfzzgzjxq = sfzzgzjxq;
    }

    public String getSfwwpfmysxq() {
        return sfwwpfmysxq;
    }

    public void setSfwwpfmysxq(String sfwwpfmysxq) {
        this.sfwwpfmysxq = sfwwpfmysxq;
    }

    public String getLpjj() {
        return lpjj;
    }

    public void setLpjj(String lpjj) {
        this.lpjj = lpjj;
    }

    public String getSbzx() {
        return sbzx;
    }

    public void setSbzx(String sbzx) {
        this.sbzx = sbzx;
    }

    public String getSgjd() {
        return sgjd;
    }

    public void setSgjd(String sgjd) {
        this.sgjd = sgjd;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public String getZwjt() {
        return zwjt;
    }

    public void setZwjt(String zwjt) {
        this.zwjt = zwjt;
    }

    public String getLhl() {
        return lhl;
    }

    public void setLhl(String lhl) {
        this.lhl = lhl;
    }

    public String getRjl() {
        return rjl;
    }

    public void setRjl(String rjl) {
        this.rjl = rjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Integer getCwgs() {
        return cwgs;
    }

    public void setCwgs(Integer cwgs) {
        this.cwgs = cwgs;
    }

    public String getJsydghxkzh() {
        return jsydghxkzh;
    }

    public void setJsydghxkzh(String jsydghxkzh) {
        this.jsydghxkzh = jsydghxkzh;
    }

    public Integer getBkbh() {
        return bkbh;
    }

    public void setBkbh(Integer bkbh) {
        this.bkbh = bkbh;
    }

    public Integer getMbsl() {
        return mbsl;
    }

    public void setMbsl(Integer mbsl) {
        this.mbsl = mbsl;
    }

    public Double getTdtz() {
        return tdtz;
    }

    public void setTdtz(Double tdtz) {
        this.tdtz = tdtz;
    }

    public Double getJhzjzmj() {
        return jhzjzmj;
    }

    public void setJhzjzmj(Double jhzjzmj) {
        this.jhzjzmj = jhzjzmj;
    }

    public Double getJhztz() {
        return jhztz;
    }

    public void setJhztz(Double jhztz) {
        this.jhztz = jhztz;
    }

    public Date getJhkgsj() {
        return jhkgsj;
    }

    public void setJhkgsj(Date jhkgsj) {
        this.jhkgsj = jhkgsj;
    }

    public Date getJhjgsj() {
        return jhjgsj;
    }

    public void setJhjgsj(Date jhjgsj) {
        this.jhjgsj = jhjgsj;
    }

    public Double getSjwctz() {
        return sjwctz;
    }

    public void setSjwctz(Double sjwctz) {
        this.sjwctz = sjwctz;
    }

    public Date getSjkgsj() {
        return sjkgsj;
    }

    public void setSjkgsj(Date sjkgsj) {
        this.sjkgsj = sjkgsj;
    }

    public Date getSjjgsj() {
        return sjjgsj;
    }

    public void setSjjgsj(Date sjjgsj) {
        this.sjjgsj = sjjgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getWygs() {
        return wygs;
    }

    public void setWygs(String wygs) {
        this.wygs = wygs;
    }
}

==> estateplat-common-1.2.3-20180412.113022-62-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfKfxm.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-5
 * @description 新建商品房开发项目表
 */
@Table(name = "fcjy_xjspf_kfxm")
public class FcjyXjspfKfxm implements Serializable {
    @Id
    private String xmid;//主键
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String xsmc;//销售名称
    private String qxh;//区县号
    private String xmdz;//项目地址
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private Date kprq;//开盘日期
    private Date rzrq;//入住日期
    private String sldh;//售楼电话
    private String sldz;//售楼地址
    private String tdsyqzh;//土地使用权证号
    private String tddj;//土地等级(土地等级字典表)
    private String ghyt;//规划用途(土地用途字典表)
    private Integer zts;//总套数
    private Double zjzmj;//总建筑面积(平方米)
    private String szfw;//四至范围
    private Double zdmj;//占地面积(平方米)
    private Integer zrzs;//自然幢数
    private Integer dqksts;//当前可售套数
    private Double dqksmj;//当前可售面积
    private Integer yydts;//已预定套数
    private Integer ysts;//已售套数
    private String sfdjglxq;//是否多家管理小区(0:不是1：是)
    private String sfzzgzjxq;//是否整治改造旧小区(0:不是1：是 )
    private String sfwwpfmysxq;//是否五万平方米以上小区(0:不是1：是)
    private String lpjj;//楼盘简介
    private String sbzx;//设备装修
    private String sgjd;//施工进度
    private String ptss;//配套设施
    private String zwjt;//周围交通
    private String lhl;//绿化率
    private String rjl;//容积率
    private Double jzmd;//建筑密度
    private Integer cwgs;//车位个数
    private String jsydghxkzh;//建设用地规划许可证号
    private Integer bkbh;//板块编号
    private Integer mbsl;//模板数量
    private Double tdtz;//土地投资（万元）
    private Double jhzjzmj;//计划总建筑面积（平方米）
    private Double jhztz;//计划总投资（万元）
    private Date jhkgsj;//计划开工时间
    private Date jhjgsj;//计划竣工时间
    private Double sjwctz;//实际完成投资（万元）
    private Date sjkgsj;//实际开工时间
    private Date sjjgsj;//实际竣工时间
    private String bz;//备注
    private String sfzx;//是否注销(0：未注销1：注销 )
    private String zxyy;//注销原因
    private String wygs;//物业公司

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXsmc() {
        return xsmc;
    }

    public void setXsmc(String xsmc) {
        this.xsmc = xsmc;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getXmdz() {
        return xmdz;
    }

    public void setXmdz(String xmdz) {
        this.xmdz = xmdz;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public Date getKprq() {
        return kprq;
    }

    public void setKprq(Date kprq) {
        this.kprq = kprq;
    }

    public Date getRzrq() {
        return rzrq;
    }

    public void setRzrq(Date rzrq) {
        this.rzrq = rzrq;
    }

    public String getSldh() {
        return sldh;
    }

    public void setSldh(String sldh) {
        this.sldh = sldh;
    }

    public String getSldz() {
        return sldz;
    }

    public void setSldz(String sldz) {
        this.sldz = sldz;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public String getSzfw() {
        return szfw;
    }

    public void setSzfw(String szfw) {
        this.szfw = szfw;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public Integer getZrzs() {
        return zrzs;
    }

    public void setZrzs(Integer zrzs) {
        this.zrzs = zrzs;
    }

    public Integer getDqksts() {
        return dqksts;
    }

    public void setDqksts(Integer dqksts) {
        this.dqksts = dqksts;
    }

    public Double getDqksmj() {
        return dqksmj;
    }

    public void setDqksmj(Double dqksmj) {
        this.dqksmj = dqksmj;
    }

    public Integer getYydts() {
        return yydts;
    }

    public void setYydts(Integer yydts) {
        this.yydts = yydts;
    }

    public Integer getYsts() {
        return ysts;
    }

    public void setYsts(Integer ysts) {
        this.ysts = ysts;
    }

    public String getSfdjglxq() {
        return sfdjglxq;
    }

    public void setSfdjglxq(String sfdjglxq) {
        this.sfdjglxq = sfdjglxq;
    }

    public String getSfzzgzjxq() {
        return sfzzgzjxq;
    }

    public void setSfzzgzjxq(String sfzzgzjxq) {
        this.sfzzgzjxq = sfzzgzjxq;
    }

    public String getSfwwpfmysxq() {
        return sfwwpfmysxq;
    }

    public void setSfwwpfmysxq(String sfwwpfmysxq) {
        this.sfwwpfmysxq = sfwwpfmysxq;
    }

    public String getLpjj() {
        return lpjj;
    }

    public void setLpjj(String lpjj) {
        this.lpjj = lpjj;
    }

    public String getSbzx() {
        return sbzx;
    }

    public void setSbzx(String sbzx) {
        this.sbzx = sbzx;
    }

    public String getSgjd() {
        return sgjd;
    }

    public void setSgjd(String sgjd) {
        this.sgjd = sgjd;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public String getZwjt() {
        return zwjt;
    }

    public void setZwjt(String zwjt) {
        this.zwjt = zwjt;
    }

    public String getLhl() {
        return lhl;
    }

    public void setLhl(String lhl) {
        this.lhl = lhl;
    }

    public String getRjl() {
        return rjl;
    }

    public void setRjl(String rjl) {
        this.rjl = rjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Integer getCwgs() {
        return cwgs;
    }

    public void setCwgs(Integer cwgs) {
        this.cwgs = cwgs;
    }

    public String getJsydghxkzh() {
        return jsydghxkzh;
    }

    public void setJsydghxkzh(String jsydghxkzh) {
        this.jsydghxkzh = jsydghxkzh;
    }

    public Integer getBkbh() {
        return bkbh;
    }

    public void setBkbh(Integer bkbh) {
        this.bkbh = bkbh;
    }

    public Integer getMbsl() {
        return mbsl;
    }

    public void setMbsl(Integer mbsl) {
        this.mbsl = mbsl;
    }

    public Double getTdtz() {
        return tdtz;
    }

    public void setTdtz(Double tdtz) {
        this.tdtz = tdtz;
    }

    public Double getJhzjzmj() {
        return jhzjzmj;
    }

    public void setJhzjzmj(Double jhzjzmj) {
        this.jhzjzmj = jhzjzmj;
    }

    public Double getJhztz() {
        return jhztz;
    }

    public void setJhztz(Double jhztz) {
        this.jhztz = jhztz;
    }

    public Date getJhkgsj() {
        return jhkgsj;
    }

    public void setJhkgsj(Date jhkgsj) {
        this.jhkgsj = jhkgsj;
    }

    public Date getJhjgsj() {
        return jhjgsj;
    }

    public void setJhjgsj(Date jhjgsj) {
        this.jhjgsj = jhjgsj;
    }

    public Double getSjwctz() {
        return sjwctz;
    }

    public void setSjwctz(Double sjwctz) {
        this.sjwctz = sjwctz;
    }

    public Date getSjkgsj() {
        return sjkgsj;
    }

    public void setSjkgsj(Date sjkgsj) {
        this.sjkgsj = sjkgsj;
    }

    public Date getSjjgsj() {
        return sjjgsj;
    }

    public void setSjjgsj(Date sjjgsj) {
        this.sjjgsj = sjjgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getWygs() {
        return wygs;
    }

    public void setWygs(String wygs) {
        this.wygs = wygs;
    }
}
